@@ -1,27 +1,37 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Dist::Zilla::Util::RoleDB::Entry::Phase;
-BEGIN {
-  $Dist::Zilla::Util::RoleDB::Entry::Phase::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::Util::RoleDB::Entry::Phase::VERSION = '0.001000';
-}
+
+our $VERSION = '0.002000';
 
 # ABSTRACT: Extracted meta-data about a role that represents a phase
 
-use Moose;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moose qw( has extends );
 use MooseX::AttributeShortcuts;
 
 extends 'Dist::Zilla::Util::RoleDB::Entry';
 
 
+
+
+
+
+
 sub is_phase {
   return 1;
 }
 
 
+
+
+
+
+
 has phase_method => (
   isa           => 'Str' =>,
   is            => ro    =>,
@@ -45,7 +55,7 @@ Dist::Zilla::Util::RoleDB::Entry::Phase - Extracted meta-data about a role that
 
 =head1 VERSION
 
-version 0.001000
+version 0.002000
 
 =head1 METHODS
 
@@ -65,7 +75,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
